@@ -6,6 +6,7 @@ use warnings;
 use base 'App::GitHooks::Plugin';
 
 # External dependencies.
+use File::Spec qw();
 use System::Command;
 
 # Internal dependencies.
@@ -25,11 +26,11 @@ allowing the commit to be completed.
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.0.2
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 
 =head1 METHODS
@@ -84,23 +85,23 @@ sub run_pre_commit_file
 
 	# Ignore deleted files.
 	return $PLUGIN_RETURN_SKIPPED
-			if $git_action eq 'D';
+		if $git_action eq 'D';
 
 	# Execute perl -cw.
-	my $path = $repository->work_tree() . '/' . $file;
+	my $path = File::Spec->catfile( $repository->work_tree(), $file );
 	my ( $pid, $stdin, $stdout, $stderr ) = System::Command->spawn( $^X, '-cw', $path );
 
 	# Retrieve the output.
 	my $output;
 	{
-			local $/ = undef;
-			$output = <$stderr>;
-			chomp( $output );
+		local $/ = undef;
+		$output = <$stderr>;
+		chomp( $output );
 	}
 
 	# Raise an exception if we didn't get "syntax OK".
 	die "$output\n"
-			if $output !~ /\Q$file syntax OK\E$/x;
+		if $output !~ /\Q$file syntax OK\E$/x;
 
 	return $PLUGIN_RETURN_PASSED;
 }
@@ -152,7 +153,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2014 Guillaume Aubert.
+Copyright 2013-2015 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
